==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Origin</source>
        <translation>Nulový bod</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Zobraziť pomocné osi</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rulers and Scrollbars</source>
        <translation>Pravítka a posuvníky</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Zobraziť pravítka</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Zobraziť posuvníky</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Kurzor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Zobraziť krížik</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Zobraziť veľký zameriavací krížik</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translation>Automatické priblíženie</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Okraj (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Pri načítaní automatické priblíženie</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Prispôsobenie Farieb</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Zamedziť zobrazeniu čierne na čiernom / biele na bielom</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Hranica svetlosti farby:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Typy čiar</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Automaticky použiť typy čiar na základnej obrazovke v zobrazení modelu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Automaticky prepnúť typ čiar v pohľade model na základnej obrazovke</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Rozsah vzoriek typov čiar podľa hrúbky čiary</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Vzor mierky pre hrúbku čiary 0,00 mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Obraz a výkon</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Number of preview entities:</source>
        <translation>Počet prvkov náhľadu:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>Limit zobrazovanej výšky textu (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Zobraziť oblúky ako čiary pod týmto uhlom (v stupňoch):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Zobraziť prvky s viac než N čiarkami súvisle:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Minimálny uhol kroku pre zobrazovanie oblúkov (v stupňoch):</translation>
    </message>
    <message>
        <location line="+144"/>
        <source>Use full resolution for Retina display</source>
        <translation>Použiť celé rozlíšenie pre Retina display</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Predvolené vyhladenie prvkov</translation>
    </message>
    <message>
        <location line="-69"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Časový limit pre zobrazenie šrafovania:</translation>
    </message>
    <message>
        <location line="+76"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Maximálny počet zobrazených bodov :</translation>
    </message>
    <message>
        <location line="+70"/>
        <source>Selection</source>
        <translation>Výber</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Zapnúť viacnásobný výber prvkov</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Plocha Grafiky</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Vzhľad</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Origin</source>
        <translation>Nulový bod</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Zobraziť pomocné osi</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rulers and Scrollbars</source>
        <translation>Pravítka a posuvníky</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Zobraziť pravítka</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Zobraziť posuvníky</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Kurzor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Zobraziť krížik</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Zobraziť veľký zameriavací krížik</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translation>Automatické priblíženie</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Okraj (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Pri načítaní automatické priblíženie</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Prispôsobenie Farieb</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Zamedziť zobrazeniu čierne na čiernom / biele na bielom</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Color lightness threshold:</source>
        <translation>Hranica svetlosti farby:</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Disable for printing</source>
        <translation>Zakázať tlač</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Linetypes</source>
        <translation>Typy čiar</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Automaticky použiť typy čiar na základnej obrazovke v zobrazení modelu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Automaticky prepnúť typ čiar v pohľade model na základnej obrazovke</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Rozsah vzoriek typov čiar podľa hrúbky čiary</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Vzor mierky pre hrúbku čiary 0,00 mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Obraz a výkon</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Number of preview entities:</source>
        <translation>Počet prvkov náhľadu:</translation>
    </message>
    <message>
        <source>Text height display threshold (px):</source>
        <translation type="vanished">Limit zobrazovanej výšky textu (px):</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Zobraziť oblúky ako čiary pod týmto uhlom (v stupňoch):</translation>
    </message>
    <message>
        <location line="+151"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Zobraziť prvky s viac než N čiarkami súvisle:</translation>
    </message>
    <message>
        <location line="-82"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Minimálny uhol kroku pre zobrazovanie oblúkov (v stupňoch):</translation>
    </message>
    <message>
        <location line="-134"/>
        <source>Use full resolution for Retina display</source>
        <translation>Použiť celé rozlíšenie pre Retina display</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Predvolené vyhladenie prvkov</translation>
    </message>
    <message>
        <location line="+265"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Časový limit pre zobrazenie šrafovania:</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Maximálny počet zobrazených bodov :</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Selection</source>
        <translation>Výber</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Zapnúť viacnásobný výber prvkov</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Plocha Grafiky</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Vzhľad</translation>
    </message>
</context>
</TS>
